==> google-cloud-securitycenter-1.12.0.tar.gz: google-cloud-securitycenter-1.12.0/google/cloud/securitycenter/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.securitycenter_v1.services.security_center.async_client import (
    SecurityCenterAsyncClient,
)
from google.cloud.securitycenter_v1.services.security_center.client import (
    SecurityCenterClient,
)
from google.cloud.securitycenter_v1.types.access import Access, Geolocation
from google.cloud.securitycenter_v1.types.asset import Asset
from google.cloud.securitycenter_v1.types.bigquery_export import BigQueryExport
from google.cloud.securitycenter_v1.types.compliance import Compliance
from google.cloud.securitycenter_v1.types.connection import Connection
from google.cloud.securitycenter_v1.types.contact_details import Contact, ContactDetails
from google.cloud.securitycenter_v1.types.exfiltration import (
    ExfilResource,
    Exfiltration,
)
from google.cloud.securitycenter_v1.types.external_system import ExternalSystem
from google.cloud.securitycenter_v1.types.file import File
from google.cloud.securitycenter_v1.types.finding import Finding
from google.cloud.securitycenter_v1.types.folder import Folder
from google.cloud.securitycenter_v1.types.iam_binding import IamBinding
from google.cloud.securitycenter_v1.types.indicator import Indicator
from google.cloud.securitycenter_v1.types.mitre_attack import MitreAttack
from google.cloud.securitycenter_v1.types.mute_config import MuteConfig
from google.cloud.securitycenter_v1.types.notification_config import NotificationConfig
from google.cloud.securitycenter_v1.types.notification_message import (
    NotificationMessage,
)
from google.cloud.securitycenter_v1.types.organization_settings import (
    OrganizationSettings,
)
from google.cloud.securitycenter_v1.types.process import EnvironmentVariable, Process
from google.cloud.securitycenter_v1.types.resource import Resource
from google.cloud.securitycenter_v1.types.run_asset_discovery_response import (
    RunAssetDiscoveryResponse,
)
from google.cloud.securitycenter_v1.types.security_marks import SecurityMarks
from google.cloud.securitycenter_v1.types.securitycenter_service import (
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    GetBigQueryExportRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetOrganizationSettingsRequest,
    GetSourceRequest,
    GroupAssetsRequest,
    GroupAssetsResponse,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAssetsRequest,
    ListAssetsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    RunAssetDiscoveryRequest,
    SetFindingStateRequest,
    SetMuteRequest,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateOrganizationSettingsRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from google.cloud.securitycenter_v1.types.source import Source
from google.cloud.securitycenter_v1.types.vulnerability import (
    Cve,
    Cvssv3,
    Reference,
    Vulnerability,
)

__all__ = (
    "SecurityCenterClient",
    "SecurityCenterAsyncClient",
    "Access",
    "Geolocation",
    "Asset",
    "BigQueryExport",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "Folder",
    "IamBinding",
    "Indicator",
    "MitreAttack",
    "MuteConfig",
    "NotificationConfig",
    "NotificationMessage",
    "OrganizationSettings",
    "EnvironmentVariable",
    "Process",
    "Resource",
    "RunAssetDiscoveryResponse",
    "SecurityMarks",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateSourceRequest",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "GetBigQueryExportRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetOrganizationSettingsRequest",
    "GetSourceRequest",
    "GroupAssetsRequest",
    "GroupAssetsResponse",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "RunAssetDiscoveryRequest",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateOrganizationSettingsRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "Source",
    "Cve",
    "Cvssv3",
    "Reference",
    "Vulnerability",
)

==> google-cloud-securitycenter-1.15.0.tar.gz: google-cloud-securitycenter-1.15.0/google/cloud/securitycenter/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.securitycenter_v1.services.security_center.async_client import (
    SecurityCenterAsyncClient,
)
from google.cloud.securitycenter_v1.services.security_center.client import (
    SecurityCenterClient,
)
from google.cloud.securitycenter_v1.types.access import (
    Access,
    Geolocation,
    ServiceAccountDelegationInfo,
)
from google.cloud.securitycenter_v1.types.asset import Asset
from google.cloud.securitycenter_v1.types.bigquery_export import BigQueryExport
from google.cloud.securitycenter_v1.types.compliance import Compliance
from google.cloud.securitycenter_v1.types.connection import Connection
from google.cloud.securitycenter_v1.types.contact_details import Contact, ContactDetails
from google.cloud.securitycenter_v1.types.container import Container
from google.cloud.securitycenter_v1.types.database import Database
from google.cloud.securitycenter_v1.types.exfiltration import (
    ExfilResource,
    Exfiltration,
)
from google.cloud.securitycenter_v1.types.external_system import ExternalSystem
from google.cloud.securitycenter_v1.types.file import File
from google.cloud.securitycenter_v1.types.finding import Finding
from google.cloud.securitycenter_v1.types.folder import Folder
from google.cloud.securitycenter_v1.types.iam_binding import IamBinding
from google.cloud.securitycenter_v1.types.indicator import Indicator
from google.cloud.securitycenter_v1.types.kubernetes import Kubernetes
from google.cloud.securitycenter_v1.types.label import Label
from google.cloud.securitycenter_v1.types.mitre_attack import MitreAttack
from google.cloud.securitycenter_v1.types.mute_config import MuteConfig
from google.cloud.securitycenter_v1.types.notification_config import NotificationConfig
from google.cloud.securitycenter_v1.types.notification_message import (
    NotificationMessage,
)
from google.cloud.securitycenter_v1.types.organization_settings import (
    OrganizationSettings,
)
from google.cloud.securitycenter_v1.types.process import EnvironmentVariable, Process
from google.cloud.securitycenter_v1.types.resource import Resource
from google.cloud.securitycenter_v1.types.run_asset_discovery_response import (
    RunAssetDiscoveryResponse,
)
from google.cloud.securitycenter_v1.types.security_marks import SecurityMarks
from google.cloud.securitycenter_v1.types.securitycenter_service import (
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    GetBigQueryExportRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetOrganizationSettingsRequest,
    GetSourceRequest,
    GroupAssetsRequest,
    GroupAssetsResponse,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAssetsRequest,
    ListAssetsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    RunAssetDiscoveryRequest,
    SetFindingStateRequest,
    SetMuteRequest,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateOrganizationSettingsRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from google.cloud.securitycenter_v1.types.source import Source
from google.cloud.securitycenter_v1.types.vulnerability import (
    Cve,
    Cvssv3,
    Reference,
    Vulnerability,
)

__all__ = (
    "SecurityCenterClient",
    "SecurityCenterAsyncClient",
    "Access",
    "Geolocation",
    "ServiceAccountDelegationInfo",
    "Asset",
    "BigQueryExport",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "Container",
    "Database",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "Folder",
    "IamBinding",
    "Indicator",
    "Kubernetes",
    "Label",
    "MitreAttack",
    "MuteConfig",
    "NotificationConfig",
    "NotificationMessage",
    "OrganizationSettings",
    "EnvironmentVariable",
    "Process",
    "Resource",
    "RunAssetDiscoveryResponse",
    "SecurityMarks",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateSourceRequest",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "GetBigQueryExportRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetOrganizationSettingsRequest",
    "GetSourceRequest",
    "GroupAssetsRequest",
    "GroupAssetsResponse",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "RunAssetDiscoveryRequest",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateOrganizationSettingsRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "Source",
    "Cve",
    "Cvssv3",
    "Reference",
    "Vulnerability",
)
